@@ -302,8 +302,8 @@ class Users(object):
 		self.email = utils.Email(
 			email=self.email_address,
 			password=self.email_password,
-			smtp_host=smpt_host,
-			smtp_port=smpt_port,)
+			smtp_host=self.smtp_host,
+			smtp_port=self.smtp_port,)
 		response = self.email.login()
 		if response["success"]:
 			return r3sponse.success_response("Successfully initialized the mail object.")
